messagingapp/msgui/unifiedviewer/inc/univiewerbodywidget.h
branchGCC_SURGE
changeset 47 5b14749788d7
parent 27 e4592d119491
parent 43 35b64624a9e7
--- a/messagingapp/msgui/unifiedviewer/inc/univiewerbodywidget.h	Thu Jun 17 09:57:06 2010 +0100
+++ b/messagingapp/msgui/unifiedviewer/inc/univiewerbodywidget.h	Thu Jul 22 16:32:06 2010 +0100
@@ -24,13 +24,12 @@
 
 class UniViewerTextItem;
 class UniViewerPixmapWidget;
+class UniViewerAudioWidget;
 class HbTextItem;
-class HbPushButton;
-//class HbGestureSceneFilter;
-class QSignalMapper;
 
 /**
  * This widget displays the body of the viewer
  */
 class UniViewerBodyWidget: public HbWidget
 {
@@ -55,27 +54,27 @@
 
     /**
      * Called to insert image content in viewer.
-     * @param medialist list of absolute paths of media.
+     * @param info Object information.
      */
-    void setPixmap(QString pixmapFile);
+    void setPixmap(UniMessageInfo *info);
 
     /**
      * Called to insert audio content in viewer.
-     * @param medialist list of absolute paths of media.
+     * @param info Object information.
      */
-    void setAudio(QString audiofile);
+    void setAudio(UniMessageInfo *info);
 
     /**
      * Called to insert video content in viewer.
-     * @param medialist list of absolute paths of media.
+     * @param info Object information.
      */
-    void setVideo(QString videofile);
+    void setVideo(UniMessageInfo *info);
 
     /**
      * Called to insert text content in viewer.
      * @param text Body text to be set.
      */
-    void setTextContent(QString text);
+    void setText(QString text);
 
     /**
      * Sets the slide counter.
@@ -127,38 +126,6 @@
      */
     QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint = QSizeF()) const;
 
-private slots:
-
-    /**
-     * called on long press on the media objects
-     */
-    void longPressed(QPointF position);
-
-    /**
-     * called from the media object's item specific menu
-     */
-    void openMedia();
-
-    /**
-     * Open a specified media file
-     */
-    void openMedia(const QString& fileName);
-
-    /**
-     * called from the media object's item specific menu
-     */
-    void saveMedia();
-
-    /**
-     * Service launch complete.
-     */
-    void handleOk(const QVariant& result);
-
-    /**
-     * Service launch errors.
-     */
-    void handleError(int errorCode, const QString& errorMessage);
-
 signals:
     /**
      * this signal is emitted when sendMessage is emitted from UniViewerTextItem.
@@ -196,17 +163,7 @@
     /**
      * Media widget for embedded audio content.
      */
-    HbPushButton *mAudioItem;
-
-    /**
-     * To setup longpress gesture on media objects
-     */
-   // HbGestureSceneFilter* gestureFilter;
-
-    /**
-     * File mapper for opening media
-     */
-    QSignalMapper* mSignalMapper;
+    UniViewerAudioWidget *mAudioItem;
 };
 
 #endif //UNIVIEWER_BODY_WIDGET_H
@@ -24,13 +24,12 @@
 
 /**
- * This widget displays the body of the viewer
+ * @class UniViewerBodyWidget
+ * @brief This widget displays the body of the viewer.
  */
 class UniViewerBodyWidget: public HbWidget